<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS><TS version="1.1" language="fr">
<defaultcodec></defaultcodec>
<context>
    <name>CBoatElementWidget</name>
    <message>
        <source>Sail information</source>
        <translation type="obsolete">Informations sur la voile</translation>
    </message>
    <message>
        <location filename="../boatdef-panel.cpp" line="145"/>
        <source>file</source>
        <translation>fichier</translation>
    </message>
    <message>
        <location filename="../boatdef-panel.cpp" line="146"/>
        <source>name</source>
        <translation>nom</translation>
    </message>
    <message>
        <location filename="../boatdef-panel.cpp" line="147"/>
        <source>Reload</source>
        <translation>Recharger</translation>
    </message>
    <message>
        <location filename="../boatdef-panel.cpp" line="148"/>
        <source>Remove</source>
        <translation>Retirer</translation>
    </message>
    <message>
        <location filename="../boatdef-panel.cpp" line="149"/>
        <source>Update</source>
        <translation>Mettre à jour</translation>
    </message>
    <message>
        <location filename="../boatdef-panel.cpp" line="144"/>
        <source>Element information</source>
        <translation>Information sur l&apos;élément</translation>
    </message>
</context>
<context>
    <name>CFileIO</name>
    <message>
        <source>Open</source>
        <translation type="obsolete">Ouvrir</translation>
    </message>
    <message>
        <source>Save</source>
        <translation type="obsolete">Enregistrer</translation>
    </message>
</context>
<context>
    <name>CFileWriter</name>
    <message>
        <location filename="../filewriter.h" line="151"/>
        <source>error</source>
        <translation>erreur</translation>
    </message>
    <message>
        <location filename="../filewriter.h" line="151"/>
        <source>There was an error writing to the selected file.</source>
        <translation>Une erreur s&apos;est produite lors de l&apos;écriture du fichier.</translation>
    </message>
    <message>
        <location filename="../filewriter.h" line="88"/>
        <source>Open</source>
        <translation>Ouvrir</translation>
    </message>
    <message>
        <location filename="../filewriter.h" line="110"/>
        <source>There was an error reading from the selected file.</source>
        <translation>Il y a eu une erreur de lecture du fichier choisi.</translation>
    </message>
    <message>
        <location filename="../filewriter.h" line="127"/>
        <source>Save</source>
        <translation>Enregistrer</translation>
    </message>
</context>
<context>
    <name>CFormBoat</name>
    <message>
        <location filename="../formboat.cpp" line="104"/>
        <source>boat</source>
        <translation>bateau</translation>
    </message>
    <message>
        <location filename="../formboat.cpp" line="105"/>
        <source>&amp;Add</source>
        <translation>&amp;Ajouter</translation>
    </message>
    <message>
        <location filename="../formboat.cpp" line="106"/>
        <source>file</source>
        <translation>fichier</translation>
    </message>
    <message>
        <location filename="../formboat.cpp" line="167"/>
        <source>Open</source>
        <translation>Ouvrir</translation>
    </message>
</context>
<context>
    <name>CFormHull</name>
    <message>
        <location filename="../formhull.cpp" line="57"/>
        <source>hull</source>
        <translation>coque</translation>
    </message>
    <message>
        <location filename="../formhull.cpp" line="58"/>
        <source>&amp;Dimensions</source>
        <translation>&amp;Dimensions</translation>
    </message>
</context>
<context>
    <name>CFormHullDefBase</name>
    <message>
        <location filename="../formhulldefbase.ui" line="20"/>
        <source>Dialog</source>
        <translation>Dialogue</translation>
    </message>
    <message>
        <location filename="../formhulldefbase.ui" line="86"/>
        <source>Deck and bottom</source>
        <translation>Pont et fond</translation>
    </message>
    <message>
        <location filename="../formhulldefbase.ui" line="104"/>
        <source>Planking</source>
        <translation>Bordé</translation>
    </message>
    <message>
        <location filename="../formhulldefbase.ui" line="116"/>
        <source>Automatic planking</source>
        <translation>Bordage automatique</translation>
    </message>
    <message>
        <location filename="../formhulldefbase.ui" line="167"/>
        <source>lower plank angle</source>
        <translation>angle du bordé inférieur</translation>
    </message>
    <message>
        <location filename="../formhulldefbase.ui" line="231"/>
        <source>top plank angle</source>
        <translation>angle du bordé supérieur</translation>
    </message>
    <message>
        <location filename="../formhulldefbase.ui" line="238"/>
        <source>Number of planks</source>
        <translation>Nombre de bordés</translation>
    </message>
    <message>
        <location filename="../formhulldefbase.ui" line="256"/>
        <source>Bottom</source>
        <translation>Fond</translation>
    </message>
    <message>
        <location filename="../formhulldefbase.ui" line="313"/>
        <source>Bottom sweep angle</source>
        <translation>Angle d&apos;avance du fond</translation>
    </message>
    <message>
        <location filename="../formhulldefbase.ui" line="334"/>
        <source>%</source>
        <translation>%</translation>
    </message>
    <message>
        <location filename="../formhulldefbase.ui" line="446"/>
        <source>Max Width</source>
        <translation>Largeur maximum</translation>
    </message>
    <message>
        <source>Bottom dead rise angle</source>
        <translation type="obsolete">Angle du fond</translation>
    </message>
    <message>
        <location filename="../formhulldefbase.ui" line="655"/>
        <source>Forward shape</source>
        <translation>Forme avant</translation>
    </message>
    <message>
        <location filename="../formhulldefbase.ui" line="662"/>
        <source>Length</source>
        <translation>Longueur</translation>
    </message>
    <message>
        <location filename="../formhulldefbase.ui" line="677"/>
        <source>Forward height </source>
        <translation>Hauteur avant </translation>
    </message>
    <message>
        <location filename="../formhulldefbase.ui" line="684"/>
        <source>Max Width position</source>
        <translation>Position de la largeur maximum</translation>
    </message>
    <message>
        <source>Side slope angle</source>
        <translation type="obsolete">Inclinaison latérale</translation>
    </message>
    <message>
        <location filename="../formhulldefbase.ui" line="706"/>
        <source>Stem angle</source>
        <translation>Angle de l&apos;étrave</translation>
    </message>
    <message>
        <location filename="../formhulldefbase.ui" line="713"/>
        <source>Transom angle</source>
        <translation>Angle du tableau</translation>
    </message>
    <message>
        <location filename="../formhulldefbase.ui" line="1752"/>
        <source>Aft height</source>
        <translation>Hauteur arrière</translation>
    </message>
    <message>
        <location filename="../formhulldefbase.ui" line="735"/>
        <source>Aft width</source>
        <translation>Largeur arrière</translation>
    </message>
    <message>
        <location filename="../formhulldefbase.ui" line="742"/>
        <source>Aft shape</source>
        <translation>Forme arrière</translation>
    </message>
    <message>
        <location filename="../formhulldefbase.ui" line="794"/>
        <source>Hull name</source>
        <translation>Nom de la coque</translation>
    </message>
    <message>
        <location filename="../formhulldefbase.ui" line="804"/>
        <source>Deck</source>
        <translation>Pont</translation>
    </message>
    <message>
        <location filename="../formhulldefbase.ui" line="1745"/>
        <source>Forward height</source>
        <translation>Hauteur avant</translation>
    </message>
    <message>
        <source>Side Planks</source>
        <translation type="obsolete">Bordés</translation>
    </message>
    <message>
        <location filename="../formhulldefbase.ui" line="1068"/>
        <source>Plank 5</source>
        <translation>Bordé 5</translation>
    </message>
    <message>
        <location filename="../formhulldefbase.ui" line="1773"/>
        <source>Chine angle</source>
        <translation>angle du bouchain</translation>
    </message>
    <message>
        <location filename="../formhulldefbase.ui" line="1766"/>
        <source>Sweep angle</source>
        <translation>angle d&apos;avance</translation>
    </message>
    <message>
        <location filename="../formhulldefbase.ui" line="1759"/>
        <source>Plank angle</source>
        <translation>angle du bordé</translation>
    </message>
    <message>
        <location filename="../formhulldefbase.ui" line="1211"/>
        <source>Plank 4</source>
        <translation>Bordé 4</translation>
    </message>
    <message>
        <location filename="../formhulldefbase.ui" line="1354"/>
        <source>Plank 3</source>
        <translation>Bordé 3</translation>
    </message>
    <message>
        <location filename="../formhulldefbase.ui" line="1640"/>
        <source>Plank 2</source>
        <translation>Bordé 2</translation>
    </message>
    <message>
        <location filename="../formhulldefbase.ui" line="1497"/>
        <source>Plank 1</source>
        <translation>Bordé 1</translation>
    </message>
    <message>
        <location filename="../formhulldefbase.ui" line="925"/>
        <source>Plank 6</source>
        <translation>Bordé 6</translation>
    </message>
    <message>
        <location filename="../formhulldefbase.ui" line="53"/>
        <source>Check</source>
        <translation>Vérifier</translation>
    </message>
    <message>
        <location filename="../formhulldefbase.ui" line="60"/>
        <source>OK</source>
        <translation>OK</translation>
    </message>
    <message>
        <location filename="../formhulldefbase.ui" line="67"/>
        <source>Cancel</source>
        <translation>Annuler</translation>
    </message>
    <message>
        <location filename="../formhulldefbase.ui" line="1826"/>
        <source>Dimensions are in millimeters and angles in degrees measured from horizontal</source>
        <translation>Les dimensions sont en millimètres et les angles en degrés par rapport à l&apos;horizontale</translation>
    </message>
    <message>
        <location filename="../formhulldefbase.ui" line="913"/>
        <source>Planks</source>
        <translation>Bordés</translation>
    </message>
    <message>
        <location filename="../formhulldefbase.ui" line="439"/>
        <source>txt_BBW</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../formhulldefbase.ui" line="467"/>
        <source>txt_BfwdHeight</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../formhulldefbase.ui" line="488"/>
        <source>txt_BLWL</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../formhulldefbase.ui" line="509"/>
        <source>txt_BaftW</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../formhulldefbase.ui" line="603"/>
        <source>txt_BaftHeight</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../formhulldefbase.ui" line="648"/>
        <source>Dead rise angle</source>
        <translation>Angle du fond</translation>
    </message>
    <message>
        <location filename="../formhulldefbase.ui" line="773"/>
        <source>txt_HullID</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../formhulldefbase.ui" line="860"/>
        <source>txt_DaftHeight</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../formhulldefbase.ui" line="881"/>
        <source>txt_DfwdHeight</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../formhulldefbase.ui" line="895"/>
        <source>Side angle</source>
        <translation></translation>
    </message>
</context>
<context>
    <name>CFormMain</name>
    <message>
        <source>to &amp;DXF</source>
        <translation type="obsolete">&amp;DXF</translation>
    </message>
    <message>
        <source>to &amp;TXT sail</source>
        <translation type="obsolete">voile &amp;TXT</translation>
    </message>
    <message>
        <source>to &amp;XML sail</source>
        <translation type="obsolete">voile &amp;XML</translation>
    </message>
    <message>
        <location filename="../formmain.cpp" line="124"/>
        <source>&amp;New</source>
        <translation>&amp;Nouveau</translation>
    </message>
    <message>
        <location filename="../formmain.cpp" line="129"/>
        <source>&amp;Open</source>
        <translation>&amp;Ouvrir</translation>
    </message>
    <message>
        <location filename="../formmain.cpp" line="131"/>
        <source>&amp;Save</source>
        <translation>&amp;Enregistrer</translation>
    </message>
    <message>
        <location filename="../formmain.cpp" line="132"/>
        <source>Save &amp;As</source>
        <translation>Enregistrer &amp;sous</translation>
    </message>
    <message>
        <location filename="../formmain.cpp" line="134"/>
        <source>&amp;Quit</source>
        <translation>&amp;Quitter</translation>
    </message>
    <message>
        <source>&amp;Dimensions</source>
        <translation type="obsolete">&amp;Dimensions</translation>
    </message>
    <message>
        <source>&amp;Mould</source>
        <translation type="obsolete">&amp;Moule</translation>
    </message>
    <message>
        <source>&amp;Patches</source>
        <translation type="obsolete">&amp;Renforts</translation>
    </message>
    <message>
        <source>&amp;Rig</source>
        <translation type="obsolete">&amp;Gréement</translation>
    </message>
    <message>
        <location filename="../formmain.cpp" line="122"/>
        <source>&amp;File</source>
        <translation>&amp;Fichier</translation>
    </message>
    <message>
        <location filename="../formmain.cpp" line="137"/>
        <source>&amp;View</source>
        <translation>&amp;Vue</translation>
    </message>
    <message>
        <location filename="../formmain.cpp" line="148"/>
        <source>&amp;Help</source>
        <translation>&amp;Aide</translation>
    </message>
    <message>
        <location filename="../formmain.cpp" line="327"/>
        <source>About Sailcut CAD</source>
        <translation>A propos de Sailcut CAD</translation>
    </message>
    <message>
        <source>error</source>
        <translation type="obsolete">erreur</translation>
    </message>
    <message>
        <source>There was an error writing to the selected file</source>
        <translation type="obsolete">Une erreur s&apos;est produite lors de l&apos;écriture du fichier</translation>
    </message>
    <message>
        <location filename="../formmain.cpp" line="150"/>
        <source>About &amp;Qt</source>
        <translation>A propos de &amp;Qt</translation>
    </message>
    <message>
        <location filename="../formmain.cpp" line="151"/>
        <source>About &amp;Sailcut CAD</source>
        <translation>A propos de &amp;Sailcut CAD</translation>
    </message>
    <message>
        <source>to &amp;Carlson plotter</source>
        <translation type="obsolete">table traçante &amp;Carlson</translation>
    </message>
    <message>
        <source>shaded view</source>
        <translation type="obsolete">vue rendu 3D</translation>
    </message>
    <message>
        <source>wireframe view</source>
        <translation type="obsolete">vue fil de fer</translation>
    </message>
    <message>
        <source>development</source>
        <translation type="obsolete">développement</translation>
    </message>
    <message>
        <source>created new sail</source>
        <translation type="obsolete">nouvelle voile créée</translation>
    </message>
    <message>
        <source>E&amp;xport 3D sail</source>
        <translation type="obsolete">E&amp;xport voile 3D</translation>
    </message>
    <message>
        <source>Export &amp;development</source>
        <translation type="obsolete">Export &amp;développement</translation>
    </message>
    <message>
        <location filename="../formmain.cpp" line="149"/>
        <source>Sailcut CAD &amp;Handbook</source>
        <translation>&amp;Manuel de Sailcut CAD</translation>
    </message>
    <message>
        <location filename="../formmain.cpp" line="130"/>
        <source>Open &amp;recent</source>
        <translation>Ouvrir fichier &amp;récent</translation>
    </message>
    <message>
        <location filename="../formmain.cpp" line="208"/>
        <source>loaded &apos;%1&apos;</source>
        <translation>chargé &apos;%1&apos;</translation>
    </message>
    <message>
        <location filename="../formmain.cpp" line="213"/>
        <source>error loading &apos;%1&apos;</source>
        <translation>erreur de chargement &apos;%1&apos;</translation>
    </message>
    <message>
        <location filename="../formmain.cpp" line="487"/>
        <source>wrote &apos;%1&apos;</source>
        <translation>écrit &apos;%1&apos;</translation>
    </message>
    <message>
        <source>There was a data printing error</source>
        <translation type="obsolete">Erreur lors de l&apos;impression des données</translation>
    </message>
    <message>
        <source>There was a development printing error</source>
        <translation type="obsolete">Erreur lors de l&apos;impression du développement</translation>
    </message>
    <message>
        <source>There was a drawing printing error</source>
        <translation type="obsolete">Erreur lors de l&apos;impression du dessin</translation>
    </message>
    <message>
        <source>data</source>
        <translation type="obsolete">données</translation>
    </message>
    <message>
        <source>drawing</source>
        <translation type="obsolete">dessin</translation>
    </message>
    <message>
        <source>develop</source>
        <translation type="obsolete">développement</translation>
    </message>
    <message>
        <source>&amp;Print</source>
        <translation type="obsolete">&amp;Imprimer</translation>
    </message>
    <message>
        <source>Sail type</source>
        <translation type="obsolete">Type de voile</translation>
    </message>
    <message>
        <source>Mainsail</source>
        <translation type="obsolete">Grand-voile</translation>
    </message>
    <message>
        <source>Jib</source>
        <translation type="obsolete">Foc</translation>
    </message>
    <message>
        <source>Sail layout</source>
        <translation type="obsolete">Type de coupe</translation>
    </message>
    <message>
        <source>Cross Cut</source>
        <translation type="obsolete">Coupe transverse</translation>
    </message>
    <message>
        <source>Horizontal Cut</source>
        <translation type="obsolete">Coupe horizontale</translation>
    </message>
    <message>
        <source>Radial Cut</source>
        <translation type="obsolete">Coupe radiale</translation>
    </message>
    <message>
        <source>Twist Foot Cut</source>
        <translation type="obsolete">Coupe twist Foot</translation>
    </message>
    <message>
        <source>Vertical Cut</source>
        <translation type="obsolete">Coupe verticale</translation>
    </message>
    <message>
        <source>Mitre Cut</source>
        <translation type="obsolete">Coupe à mitre</translation>
    </message>
    <message>
        <source> sections,   </source>
        <translation type="obsolete">sections,    </translation>
    </message>
    <message>
        <source> head gores.</source>
        <translation type="obsolete">fuseaux de tête.</translation>
    </message>
    <message>
        <source>Rig </source>
        <translation type="obsolete">Gréement</translation>
    </message>
    <message>
        <source>Boat LOA</source>
        <translation type="obsolete">Longueur du bateau</translation>
    </message>
    <message>
        <source>Fore triangle hoist I</source>
        <translation type="obsolete">Hauteur I du triangle avant</translation>
    </message>
    <message>
        <source>Fore triangle base J</source>
        <translation type="obsolete">Base J du triangle avant</translation>
    </message>
    <message>
        <source>Tack position X</source>
        <translation type="obsolete">Position X de l&apos;amure</translation>
    </message>
    <message>
        <source>Tack height Y</source>
        <translation type="obsolete">Hauteur Y de l&apos;amure</translation>
    </message>
    <message>
        <source>Sail dimensions</source>
        <translation type="obsolete">Dimensions de la voile</translation>
    </message>
    <message>
        <source>Luff length</source>
        <translation type="obsolete">Longueur guindant</translation>
    </message>
    <message>
        <source>Mast rake</source>
        <translation type="obsolete">Quête du mat</translation>
    </message>
    <message>
        <source>Gaff angle wrt luff</source>
        <translation type="obsolete">Angle vergue / guindant</translation>
    </message>
    <message>
        <source>Gaff length</source>
        <translation type="obsolete">Longueur vergue</translation>
    </message>
    <message>
        <source>Foot length</source>
        <translation type="obsolete">Longueur bordure</translation>
    </message>
    <message>
        <source>Leech length</source>
        <translation type="obsolete">Longueur chute</translation>
    </message>
    <message>
        <source>Shape of edges</source>
        <translation type="obsolete">Forme des bords</translation>
    </message>
    <message>
        <source>Luff round</source>
        <translation type="obsolete">Rond du guindant</translation>
    </message>
    <message>
        <source>Gaff round</source>
        <translation type="obsolete">Rond de la vergue</translation>
    </message>
    <message>
        <source>Leech round</source>
        <translation type="obsolete">Rond de la chute</translation>
    </message>
    <message>
        <source>Foot round</source>
        <translation type="obsolete">Rond de la bordure</translation>
    </message>
    <message>
        <source>Luff round position</source>
        <translation type="obsolete">Position du rond de guindant</translation>
    </message>
    <message>
        <source>Gaff round position</source>
        <translation type="obsolete">Position du rond de la gaffe</translation>
    </message>
    <message>
        <source>Leech round position</source>
        <translation type="obsolete">Position du rond de chute</translation>
    </message>
    <message>
        <source>Foot round position</source>
        <translation type="obsolete">Position du rond de bordure</translation>
    </message>
    <message>
        <source>Sail settings</source>
        <translation type="obsolete">Réglage de la voile</translation>
    </message>
    <message>
        <source>Twist angle</source>
        <translation type="obsolete">Angle de vrillage</translation>
    </message>
    <message>
        <source>Sheeting angle</source>
        <translation type="obsolete">Angle d&apos;ouverture</translation>
    </message>
    <message>
        <source>Cloth seams and hems</source>
        <translation type="obsolete">Tissu, coutures et ourlets</translation>
    </message>
    <message>
        <source>Cloth width</source>
        <translation type="obsolete">Largeur du tissu</translation>
    </message>
    <message>
        <source>Seams width</source>
        <translation type="obsolete">Largeur des coutures</translation>
    </message>
    <message>
        <source>Leech hem width</source>
        <translation type="obsolete">Largeur pour ourlet chute</translation>
    </message>
    <message>
        <source>Other hem width</source>
        <translation type="obsolete">Largeur pour autres ourlets</translation>
    </message>
    <message>
        <source>Sail mould</source>
        <translation type="obsolete">Moule de voile</translation>
    </message>
    <message>
        <source>Luff factor</source>
        <translation type="obsolete">Forme guindant</translation>
    </message>
    <message>
        <source>Depth</source>
        <translation type="obsolete">Creux</translation>
    </message>
    <message>
        <source>Leech factor</source>
        <translation type="obsolete">Forme chute</translation>
    </message>
    <message>
        <source>Top profile</source>
        <translation type="obsolete">Profil supérieur</translation>
    </message>
    <message>
        <source>Mid profile at h = </source>
        <translation type="obsolete">Profil médian à h =</translation>
    </message>
    <message>
        <source>Bottom profile</source>
        <translation type="obsolete">Profil inférieur</translation>
    </message>
    <message>
        <location filename="../formmain.cpp" line="138"/>
        <source>Language</source>
        <translation>Langue</translation>
    </message>
    <message>
        <source>Mast/Luff rake</source>
        <translation type="obsolete">Quête du mât / guidant</translation>
    </message>
    <message>
        <source> head gores,   </source>
        <translation type="obsolete">fuseaux de tête,</translation>
    </message>
    <message>
        <source> luff gore.</source>
        <translation type="obsolete">fuseau coté guindant.</translation>
    </message>
    <message>
        <source>Wing</source>
        <translation type="obsolete">Aile</translation>
    </message>
    <message>
        <source> luff gores.</source>
        <translation type="obsolete">fuseaux de guindant.</translation>
    </message>
    <message>
        <source>E&amp;xport &amp;development</source>
        <translation type="obsolete">E&amp;xport développement</translation>
    </message>
    <message>
        <source>to &amp;hand-plotting format</source>
        <translation type="obsolete">format coupe &amp;manuelle</translation>
    </message>
    <message>
        <source>deg</source>
        <translation type="obsolete">deg</translation>
    </message>
    <message>
        <source>to &amp;Hand-plotting format</source>
        <translation type="obsolete">pour traçage &amp;manuel</translation>
    </message>
    <message>
        <location filename="../formmain.cpp" line="125"/>
        <source>sail</source>
        <translation>voile</translation>
    </message>
    <message>
        <location filename="../formmain.cpp" line="126"/>
        <source>hull</source>
        <translation>coque</translation>
    </message>
    <message>
        <location filename="../formmain.cpp" line="127"/>
        <source>rig</source>
        <translation>gréement</translation>
    </message>
    <message>
        <location filename="../formmain.cpp" line="128"/>
        <source>boat</source>
        <translation>bateau</translation>
    </message>
    <message>
        <location filename="../formmain.cpp" line="141"/>
        <source>&amp;Window</source>
        <translation>F&amp;enêtre</translation>
    </message>
    <message>
        <location filename="../formmain.cpp" line="142"/>
        <source>&amp;Close</source>
        <translation>&amp;Fermer</translation>
    </message>
    <message>
        <location filename="../formmain.cpp" line="143"/>
        <source>Close &amp;All</source>
        <translation>&amp;Tout fermer</translation>
    </message>
    <message>
        <location filename="../formmain.cpp" line="144"/>
        <source>&amp;Tile</source>
        <translation>&amp;Mosaic</translation>
    </message>
    <message>
        <location filename="../formmain.cpp" line="145"/>
        <source>&amp;Cascade</source>
        <translation>&amp;Cascade</translation>
    </message>
    <message>
        <location filename="../formmain.cpp" line="200"/>
        <source>unknown document type &apos;%1&apos;</source>
        <translation>Document inconnu type &apos;%1&apos;</translation>
    </message>
    <message>
        <location filename="../formmain.cpp" line="444"/>
        <source>Open</source>
        <translation>Ouvrir</translation>
    </message>
</context>
<context>
    <name>CFormMould</name>
    <message>
        <location filename="../formmould.cpp" line="60"/>
        <source>&amp;Cancel</source>
        <translation>&amp;Annuler</translation>
    </message>
    <message>
        <location filename="../formmould.cpp" line="66"/>
        <source>Vertical repartition</source>
        <translation>Répartition verticale</translation>
    </message>
    <message>
        <location filename="../formmould.cpp" line="42"/>
        <source>Sail mould</source>
        <translation>Moule de voile</translation>
    </message>
    <message>
        <source>&amp;Help</source>
        <translation type="obsolete">&amp;Aide</translation>
    </message>
    <message>
        <location filename="../formmould.cpp" line="56"/>
        <source>&amp;OK</source>
        <translation>&amp;OK</translation>
    </message>
    <message>
        <location filename="../formmould.cpp" line="77"/>
        <source>Top profile</source>
        <translation>Profil supérieur</translation>
    </message>
    <message>
        <location filename="../formmould.cpp" line="78"/>
        <source>Middle profile</source>
        <translation>Profil médian</translation>
    </message>
    <message>
        <location filename="../formmould.cpp" line="79"/>
        <source>Bottom profile</source>
        <translation>Profil inférieur</translation>
    </message>
</context>
<context>
    <name>CFormPanelGroup</name>
    <message>
        <location filename="../formpanelgroup.cpp" line="56"/>
        <source>panels</source>
        <translation>panneau</translation>
    </message>
</context>
<context>
    <name>CFormPrint</name>
    <message>
        <location filename="../formprint.cpp" line="186"/>
        <source>&amp;Print</source>
        <translation>&amp;Imprimer</translation>
    </message>
    <message>
        <location filename="../formprint.cpp" line="189"/>
        <source>&amp;Cancel</source>
        <translation>&amp;Annuler</translation>
    </message>
    <message>
        <location filename="../formprint.cpp" line="165"/>
        <source>Scale</source>
        <translation>Echelle</translation>
    </message>
</context>
<context>
    <name>CFormRig</name>
    <message>
        <source>&amp;New</source>
        <translation type="obsolete">&amp;Nouveau</translation>
    </message>
    <message>
        <source>sail &amp;definition</source>
        <translation type="obsolete">&amp;définition de voile</translation>
    </message>
    <message>
        <source>3D &amp;sail</source>
        <translation type="obsolete">&amp;voile 3D</translation>
    </message>
    <message>
        <source>&amp;Add sail</source>
        <translation type="obsolete">&amp;Ajouter une voile</translation>
    </message>
    <message>
        <source>&amp;Open</source>
        <translation type="obsolete">&amp;Ouvrir</translation>
    </message>
    <message>
        <source>&amp;Save</source>
        <translation type="obsolete">&amp;Enregistrer</translation>
    </message>
    <message>
        <source>Save &amp;As</source>
        <translation type="obsolete">Enregistrer &amp;sous</translation>
    </message>
    <message>
        <source>&amp;Close</source>
        <translation type="obsolete">&amp;Fermer</translation>
    </message>
    <message>
        <source>&amp;File</source>
        <translation type="obsolete">&amp;Fichier</translation>
    </message>
    <message>
        <source>error</source>
        <translation type="obsolete">erreur</translation>
    </message>
    <message>
        <source>There was an error writing to the selected file</source>
        <translation type="obsolete">Une erreur s&apos;est produite lors de l&apos;écriture du fichier</translation>
    </message>
    <message>
        <source>Rig</source>
        <translation type="obsolete">Gréement</translation>
    </message>
    <message>
        <source>Open &amp;recent</source>
        <translation type="obsolete">Ouvrir fichier &amp;récent</translation>
    </message>
    <message>
        <location filename="../formrig.cpp" line="59"/>
        <source>rig</source>
        <translation>gréement</translation>
    </message>
    <message>
        <location filename="../formrig.cpp" line="60"/>
        <source>&amp;Dimensions</source>
        <translation>&amp;Dimensions</translation>
    </message>
</context>
<context>
    <name>CFormRigDefBase</name>
    <message>
        <location filename="../formrigdefbase.ui" line="26"/>
        <source>Rig dimensions</source>
        <translation>Dimension du gréement</translation>
    </message>
    <message>
        <location filename="../formrigdefbase.ui" line="64"/>
        <source>Cancel</source>
        <translation>Annuler</translation>
    </message>
    <message>
        <location filename="../formrigdefbase.ui" line="51"/>
        <source>OK</source>
        <translation>OK</translation>
    </message>
    <message>
        <location filename="../formrigdefbase.ui" line="291"/>
        <source>Spreaders</source>
        <translation>Barres de flèche</translation>
    </message>
    <message>
        <location filename="../formrigdefbase.ui" line="338"/>
        <source>= SPNB</source>
        <translation>= SPNB</translation>
    </message>
    <message>
        <location filename="../formrigdefbase.ui" line="345"/>
        <source>Number of spreaders</source>
        <translation>Nombre de barres de flèche</translation>
    </message>
    <message>
        <location filename="../formrigdefbase.ui" line="361"/>
        <source>Spreader height</source>
        <translation>Hauteur barre de flèche</translation>
    </message>
    <message>
        <location filename="../formrigdefbase.ui" line="385"/>
        <source>txt_SPH2</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../formrigdefbase.ui" line="407"/>
        <source>txt_SPH1</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../formrigdefbase.ui" line="429"/>
        <source>txt_SPH3</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../formrigdefbase.ui" line="445"/>
        <source>SPH2</source>
        <translation>SPH2</translation>
    </message>
    <message>
        <location filename="../formrigdefbase.ui" line="458"/>
        <source>SPH3</source>
        <translation>SPH3</translation>
    </message>
    <message>
        <location filename="../formrigdefbase.ui" line="471"/>
        <source>SPH1</source>
        <translation>SPH1</translation>
    </message>
    <message>
        <location filename="../formrigdefbase.ui" line="487"/>
        <source>Spreader length</source>
        <translation>Longueur barre de flèche</translation>
    </message>
    <message>
        <location filename="../formrigdefbase.ui" line="505"/>
        <source>SPW3</source>
        <translation>SPW3</translation>
    </message>
    <message>
        <location filename="../formrigdefbase.ui" line="518"/>
        <source>txt_SPW3</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../formrigdefbase.ui" line="534"/>
        <source>SPW1</source>
        <translation>SPW1</translation>
    </message>
    <message>
        <location filename="../formrigdefbase.ui" line="547"/>
        <source>txt_SPW1</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../formrigdefbase.ui" line="563"/>
        <source>SPW2</source>
        <translation>SPW2</translation>
    </message>
    <message>
        <location filename="../formrigdefbase.ui" line="576"/>
        <source>txt_SPW2</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../formrigdefbase.ui" line="90"/>
        <source>Shrouds</source>
        <translation>Hauban</translation>
    </message>
    <message>
        <location filename="../formrigdefbase.ui" line="114"/>
        <source>Cap shroud base width</source>
        <translation>Base du hauban de tête</translation>
    </message>
    <message>
        <location filename="../formrigdefbase.ui" line="133"/>
        <source>= CSH</source>
        <translation>= CSH</translation>
    </message>
    <message>
        <location filename="../formrigdefbase.ui" line="152"/>
        <source>Lower shroud base width </source>
        <translation>Base bas hauban</translation>
    </message>
    <message>
        <location filename="../formrigdefbase.ui" line="171"/>
        <source>txt_LSB</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../formrigdefbase.ui" line="193"/>
        <source>txt_CSH</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../formrigdefbase.ui" line="215"/>
        <source>= CSB</source>
        <translation>= CSB</translation>
    </message>
    <message>
        <location filename="../formrigdefbase.ui" line="234"/>
        <source>Cap shroud height</source>
        <translation>Hauteur hauban de tête</translation>
    </message>
    <message>
        <location filename="../formrigdefbase.ui" line="253"/>
        <source>txt_CSB</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../formrigdefbase.ui" line="275"/>
        <source>= LSB</source>
        <translation>= LSB</translation>
    </message>
    <message>
        <location filename="../formrigdefbase.ui" line="1384"/>
        <source>Fore triangle</source>
        <translation>Triangle avant</translation>
    </message>
    <message>
        <location filename="../formrigdefbase.ui" line="1421"/>
        <source>txt_foreI</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../formrigdefbase.ui" line="1431"/>
        <source>= I</source>
        <translation>= I</translation>
    </message>
    <message>
        <location filename="../formrigdefbase.ui" line="1450"/>
        <source>txt_foreJ</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../formrigdefbase.ui" line="1460"/>
        <source>= J</source>
        <translation>= J</translation>
    </message>
    <message>
        <location filename="../formrigdefbase.ui" line="1467"/>
        <source>Fore triangle base</source>
        <translation>Base triangle avant</translation>
    </message>
    <message>
        <location filename="../formrigdefbase.ui" line="1474"/>
        <source>Fore triangle hoist</source>
        <translation>Hauteur triangle avant</translation>
    </message>
    <message>
        <location filename="../formrigdefbase.ui" line="1091"/>
        <source>Mast</source>
        <translation>Mât</translation>
    </message>
    <message>
        <location filename="../formrigdefbase.ui" line="1103"/>
        <source>Mast width</source>
        <translation>Largeur du mât</translation>
    </message>
    <message>
        <location filename="../formrigdefbase.ui" line="1110"/>
        <source>= MW</source>
        <translation>= MW</translation>
    </message>
    <message>
        <location filename="../formrigdefbase.ui" line="1123"/>
        <source>txt_MW</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../formrigdefbase.ui" line="1139"/>
        <source>txt_MC</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../formrigdefbase.ui" line="1149"/>
        <source>= MC</source>
        <translation>= MC</translation>
    </message>
    <message>
        <location filename="../formrigdefbase.ui" line="1156"/>
        <source>Mast cord</source>
        <translation>Corde du mât</translation>
    </message>
    <message>
        <location filename="../formrigdefbase.ui" line="1166"/>
        <source>lbl_MRkD</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../formrigdefbase.ui" line="1176"/>
        <source>= MRkD</source>
        <translation>= MRkD</translation>
    </message>
    <message>
        <location filename="../formrigdefbase.ui" line="1183"/>
        <source>Mast rake angle</source>
        <translation>Angle de quête du mât</translation>
    </message>
    <message>
        <location filename="../formrigdefbase.ui" line="1202"/>
        <source>txt_MH</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../formrigdefbase.ui" line="1212"/>
        <source>txt_MRnd</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../formrigdefbase.ui" line="1238"/>
        <source>Mast rake</source>
        <translation>Quête du mât</translation>
    </message>
    <message>
        <location filename="../formrigdefbase.ui" line="1245"/>
        <source>= MRkM</source>
        <translation>= MRkM</translation>
    </message>
    <message>
        <location filename="../formrigdefbase.ui" line="1264"/>
        <source>txt_MRkM</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../formrigdefbase.ui" line="1286"/>
        <source>Mast height</source>
        <translation>Hauteur du mât</translation>
    </message>
    <message>
        <location filename="../formrigdefbase.ui" line="1293"/>
        <source>= MH</source>
        <translation>= MH</translation>
    </message>
    <message>
        <location filename="../formrigdefbase.ui" line="1300"/>
        <source>= MRnd</source>
        <translation>= MRnd</translation>
    </message>
    <message>
        <location filename="../formrigdefbase.ui" line="1319"/>
        <source>Mast round</source>
        <translation>Rond du mât</translation>
    </message>
    <message>
        <location filename="../formrigdefbase.ui" line="1326"/>
        <source>= MRndPos</source>
        <translation>= MRndPos</translation>
    </message>
    <message>
        <location filename="../formrigdefbase.ui" line="1345"/>
        <source>Mast round position </source>
        <translation>Position du rond du mât </translation>
    </message>
    <message>
        <location filename="../formrigdefbase.ui" line="604"/>
        <source>Mainsail</source>
        <translation>Grand-voile</translation>
    </message>
    <message>
        <location filename="../formrigdefbase.ui" line="631"/>
        <source>lbl_MS_LuffRP</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../formrigdefbase.ui" line="653"/>
        <source>@ </source>
        <translation>@ </translation>
    </message>
    <message>
        <location filename="../formrigdefbase.ui" line="678"/>
        <source>lbl_MS_LuffR</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../formrigdefbase.ui" line="703"/>
        <source>lbl_MS_TackY</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../formrigdefbase.ui" line="725"/>
        <source>Y =</source>
        <translation>Y =</translation>
    </message>
    <message>
        <location filename="../formrigdefbase.ui" line="750"/>
        <source>lbl_MS_TackX</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../formrigdefbase.ui" line="766"/>
        <source>X =</source>
        <translation>X =</translation>
    </message>
    <message>
        <location filename="../formrigdefbase.ui" line="782"/>
        <source>Tack</source>
        <translation>Amure</translation>
    </message>
    <message>
        <location filename="../formrigdefbase.ui" line="820"/>
        <source>lbl_MS_LuffL</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../formrigdefbase.ui" line="836"/>
        <source>= MSL</source>
        <translation>= MSL</translation>
    </message>
    <message>
        <location filename="../formrigdefbase.ui" line="855"/>
        <source>Luff length </source>
        <translation>Longueur du guindant</translation>
    </message>
    <message>
        <location filename="../formrigdefbase.ui" line="874"/>
        <source>Luff round</source>
        <translation>Rond du guindant</translation>
    </message>
    <message>
        <location filename="../formrigdefbase.ui" line="896"/>
        <source>lbl_MS_Rake</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../formrigdefbase.ui" line="912"/>
        <source>= MSR</source>
        <translation>= MSR</translation>
    </message>
    <message>
        <location filename="../formrigdefbase.ui" line="931"/>
        <source>Luff rake</source>
        <translation>Inclinaison du guindant</translation>
    </message>
    <message>
        <location filename="../formrigdefbase.ui" line="966"/>
        <source>Tack height </source>
        <translation>Hauteur de l&apos;amure  </translation>
    </message>
    <message>
        <location filename="../formrigdefbase.ui" line="985"/>
        <source>txt_BAD</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../formrigdefbase.ui" line="1007"/>
        <source>= BAD</source>
        <translation>= BAD</translation>
    </message>
    <message>
        <location filename="../formrigdefbase.ui" line="1027"/>
        <source>Head height</source>
        <translation>Hauteur de tête</translation>
    </message>
    <message>
        <location filename="../formrigdefbase.ui" line="1040"/>
        <source>= HAD</source>
        <translation>= HAD</translation>
    </message>
    <message>
        <location filename="../formrigdefbase.ui" line="1059"/>
        <source>txt_HAD</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../formrigdefbase.ui" line="38"/>
        <source>Check</source>
        <translation>Vérifier</translation>
    </message>
    <message>
        <location filename="../formrigdefbase.ui" line="1544"/>
        <source>All dimensions are in millimeter and angles in degrees</source>
        <translation>Toutes les dimensions sont en millimetre et les angles en degrés</translation>
    </message>
    <message>
        <source>Rig ID</source>
        <translation type="obsolete">Identification du gréement</translation>
    </message>
    <message>
        <location filename="../formrigdefbase.ui" line="1490"/>
        <source>Description of rig</source>
        <translation>Description du gréement</translation>
    </message>
    <message>
        <location filename="../formrigdefbase.ui" line="1509"/>
        <source>Rig name</source>
        <translation>Nom du gréement</translation>
    </message>
</context>
<context>
    <name>CFormSail</name>
    <message>
        <location filename="../formsail.cpp" line="74"/>
        <source>sail</source>
        <translation>voile</translation>
    </message>
    <message>
        <location filename="../formsail.cpp" line="77"/>
        <source>&amp;Print</source>
        <translation>&amp;Imprimer</translation>
    </message>
    <message>
        <location filename="../formsail.cpp" line="78"/>
        <source>data</source>
        <translation>données</translation>
    </message>
    <message>
        <location filename="../formsail.cpp" line="79"/>
        <source>drawing</source>
        <translation>dessin</translation>
    </message>
    <message>
        <location filename="../formsail.cpp" line="112"/>
        <source>development</source>
        <translation>développement</translation>
    </message>
    <message>
        <location filename="../formsail.cpp" line="83"/>
        <source>E&amp;xport 3D sail</source>
        <translation>E&amp;xport voile 3D</translation>
    </message>
    <message>
        <location filename="../formsail.cpp" line="95"/>
        <source>to &amp;DXF</source>
        <translation>&amp;DXF</translation>
    </message>
    <message>
        <location filename="../formsail.cpp" line="102"/>
        <source>to &amp;TXT sail</source>
        <translation>voile &amp;TXT</translation>
    </message>
    <message>
        <location filename="../formsail.cpp" line="103"/>
        <source>to &amp;XML sail</source>
        <translation>voile &amp;XML</translation>
    </message>
    <message>
        <location filename="../formsail.cpp" line="93"/>
        <source>Export &amp;development</source>
        <translation>Export &amp;développement</translation>
    </message>
    <message>
        <location filename="../formsail.cpp" line="94"/>
        <source>to &amp;Carlson plotter</source>
        <translation>table traçante &amp;Carlson</translation>
    </message>
    <message>
        <location filename="../formsail.cpp" line="98"/>
        <source>to &amp;Hand-plotting format</source>
        <translation>pour traçage &amp;manuel</translation>
    </message>
    <message>
        <location filename="../formsail.cpp" line="106"/>
        <source>&amp;Dimensions</source>
        <translation>&amp;Dimensions</translation>
    </message>
    <message>
        <location filename="../formsail.cpp" line="107"/>
        <source>&amp;Mould</source>
        <translation>&amp;Moule</translation>
    </message>
    <message>
        <location filename="../formsail.cpp" line="108"/>
        <source>&amp;Patches</source>
        <translation>&amp;Renforts</translation>
    </message>
    <message>
        <source>error</source>
        <translation type="obsolete">erreur</translation>
    </message>
    <message>
        <source>There was a data printing error</source>
        <translation type="obsolete">Erreur lors de l&apos;impression des données</translation>
    </message>
    <message>
        <source>There was a development printing error</source>
        <translation type="obsolete">Erreur lors de l&apos;impression du développement</translation>
    </message>
    <message>
        <source>There was a drawing printing error</source>
        <translation type="obsolete">Erreur lors de l&apos;impression du dessin</translation>
    </message>
    <message>
        <location filename="../formsail.cpp" line="100"/>
        <source>to &amp;SVG</source>
        <translation>&amp;SVG</translation>
    </message>
    <message>
        <location filename="../formsail.cpp" line="96"/>
        <source>to DXF (split)</source>
        <translation>DXF (divisé)</translation>
    </message>
</context>
<context>
    <name>CFormSailDef</name>
    <message>
        <location filename="../formsaildef.cpp" line="1143"/>
        <source>Sail corners coordinates</source>
        <translation>Coordonnées des coins de la voile</translation>
    </message>
    <message>
        <location filename="../formsaildef.cpp" line="1144"/>
        <source>tack</source>
        <translation>amure</translation>
    </message>
    <message>
        <location filename="../formsaildef.cpp" line="1145"/>
        <source>clew</source>
        <translation>écoute</translation>
    </message>
    <message>
        <location filename="../formsaildef.cpp" line="1146"/>
        <source>head</source>
        <translation>tête</translation>
    </message>
    <message>
        <location filename="../formsaildef.cpp" line="1147"/>
        <source>peak</source>
        <translation>pic</translation>
    </message>
    <message>
        <source>IRC width measurements</source>
        <translation type="obsolete">Largeurs mesurées IRC</translation>
    </message>
    <message>
        <location filename="../formsaildef.cpp" line="1152"/>
        <source>Sail width measurements </source>
        <translation>Mesures de la largeur de la voile </translation>
    </message>
</context>
<context>
    <name>CFormSailDefBase</name>
    <message>
        <location filename="../formsaildefbase.ui" line="25"/>
        <source>Sail definition</source>
        <translation>Définition de la voile</translation>
    </message>
    <message>
        <location filename="../formsaildefbase.ui" line="43"/>
        <source>Sail dimensions</source>
        <translation>Dimensions de la voile</translation>
    </message>
    <message>
        <location filename="../formsaildefbase.ui" line="1681"/>
        <source>mm</source>
        <translation>mm</translation>
    </message>
    <message>
        <location filename="../formsaildefbase.ui" line="212"/>
        <source>Round position</source>
        <translation>Position du rond</translation>
    </message>
    <message>
        <location filename="../formsaildefbase.ui" line="146"/>
        <source>Luff length</source>
        <translation>Longueur guindant</translation>
    </message>
    <message>
        <location filename="../formsaildefbase.ui" line="165"/>
        <source>Foot length</source>
        <translation>Longueur bordure</translation>
    </message>
    <message>
        <location filename="../formsaildefbase.ui" line="191"/>
        <source>Leech length</source>
        <translation>Longueur chute</translation>
    </message>
    <message>
        <location filename="../formsaildefbase.ui" line="231"/>
        <source>Gaff length</source>
        <translation>Longueur vergue</translation>
    </message>
    <message>
        <location filename="../formsaildefbase.ui" line="238"/>
        <source>Leech round</source>
        <translation>Rond de la chute</translation>
    </message>
    <message>
        <location filename="../formsaildefbase.ui" line="354"/>
        <source>Gaff round</source>
        <translation>Rond de la vergue</translation>
    </message>
    <message>
        <location filename="../formsaildefbase.ui" line="245"/>
        <source>Luff round</source>
        <translation>Rond du guindant</translation>
    </message>
    <message>
        <location filename="../formsaildefbase.ui" line="252"/>
        <source>Foot round</source>
        <translation>Rond de la bordure</translation>
    </message>
    <message>
        <location filename="../formsaildefbase.ui" line="1269"/>
        <source>%</source>
        <translation>%</translation>
    </message>
    <message>
        <location filename="../formsaildefbase.ui" line="1450"/>
        <source>deg</source>
        <translation>deg</translation>
    </message>
    <message>
        <location filename="../formsaildefbase.ui" line="361"/>
        <source>Gaff angle from luff</source>
        <translation>Angle vergue / guindant</translation>
    </message>
    <message>
        <location filename="../formsaildefbase.ui" line="549"/>
        <source>Rig geometry</source>
        <translation>Géométrie du gréement</translation>
    </message>
    <message>
        <location filename="../formsaildefbase.ui" line="662"/>
        <source>Fore triangle base  J</source>
        <translation>Base J du triangle avant</translation>
    </message>
    <message>
        <location filename="../formsaildefbase.ui" line="636"/>
        <source>Tack height</source>
        <translation>Hauteur du point d&apos;amure</translation>
    </message>
    <message>
        <location filename="../formsaildefbase.ui" line="824"/>
        <source>Distance tack to stem</source>
        <translation>Distance étrave-amure </translation>
    </message>
    <message>
        <location filename="../formsaildefbase.ui" line="576"/>
        <source>Main sail</source>
        <translation>Grand-voile</translation>
    </message>
    <message>
        <location filename="../formsaildefbase.ui" line="602"/>
        <source>Jib</source>
        <translation>Foc</translation>
    </message>
    <message>
        <location filename="../formsaildefbase.ui" line="629"/>
        <source>Fore triangle hoist  I</source>
        <translation>Hauteur I du triangle avant</translation>
    </message>
    <message>
        <location filename="../formsaildefbase.ui" line="681"/>
        <source>Boat length LOA</source>
        <translation>Longueur du bateau</translation>
    </message>
    <message>
        <source>Mast / Luff rake</source>
        <translation type="obsolete">Quête du mât / guidant</translation>
    </message>
    <message>
        <location filename="../formsaildefbase.ui" line="1460"/>
        <source>Cloth</source>
        <translation>Tissus</translation>
    </message>
    <message>
        <location filename="../formsaildefbase.ui" line="1626"/>
        <source>Seam width</source>
        <translation>Largeur coutures</translation>
    </message>
    <message>
        <location filename="../formsaildefbase.ui" line="1594"/>
        <source>Cloth width</source>
        <translation>Largeur tissu</translation>
    </message>
    <message>
        <location filename="../formsaildefbase.ui" line="905"/>
        <source>Layout</source>
        <translation>Coupe</translation>
    </message>
    <message>
        <location filename="../formsaildefbase.ui" line="1157"/>
        <source>Mitre cut</source>
        <translation>Coupe mître</translation>
    </message>
    <message>
        <location filename="../formsaildefbase.ui" line="929"/>
        <source>Cross cut</source>
        <translation>Coupe transversale</translation>
    </message>
    <message>
        <location filename="../formsaildefbase.ui" line="948"/>
        <source>Twist foot</source>
        <translation>Coupe twist</translation>
    </message>
    <message>
        <location filename="../formsaildefbase.ui" line="1071"/>
        <source>Horizontal cut</source>
        <translation>Coupe horizontale</translation>
    </message>
    <message>
        <location filename="../formsaildefbase.ui" line="967"/>
        <source>Number of sections</source>
        <translation>Nbre de sections</translation>
    </message>
    <message>
        <location filename="../formsaildefbase.ui" line="1027"/>
        <source>Number of radial gores</source>
        <translation>Nbre de fuseaux radiaux</translation>
    </message>
    <message>
        <location filename="../formsaildefbase.ui" line="1119"/>
        <source>Radial cut</source>
        <translation>Coupe radiale</translation>
    </message>
    <message>
        <location filename="../formsaildefbase.ui" line="1090"/>
        <source>Vertical cut</source>
        <translation>Coupe verticale</translation>
    </message>
    <message>
        <location filename="../formsaildefbase.ui" line="1205"/>
        <source>Sail shape</source>
        <translation>Forme de voile</translation>
    </message>
    <message>
        <location filename="../formsaildefbase.ui" line="1307"/>
        <source>Top depth</source>
        <translation>Creux en haut</translation>
    </message>
    <message>
        <location filename="../formsaildefbase.ui" line="1329"/>
        <source>Mid depth</source>
        <translation>Creux au milieu</translation>
    </message>
    <message>
        <location filename="../formsaildefbase.ui" line="1351"/>
        <source>Foot depth</source>
        <translation>Creux de bordure</translation>
    </message>
    <message>
        <location filename="../formsaildefbase.ui" line="1411"/>
        <source>Twist angle</source>
        <translation>Angle de vrillage</translation>
    </message>
    <message>
        <location filename="../formsaildefbase.ui" line="885"/>
        <source>OK</source>
        <translation>OK</translation>
    </message>
    <message>
        <location filename="../formsaildefbase.ui" line="869"/>
        <source>Cancel</source>
        <translation>Annuler</translation>
    </message>
    <message>
        <location filename="../formsaildefbase.ui" line="1610"/>
        <source>Leech hem</source>
        <translation>Ourlet chute</translation>
    </message>
    <message>
        <location filename="../formsaildefbase.ui" line="1516"/>
        <source>Other hems</source>
        <translation>Ourlet autres</translation>
    </message>
    <message>
        <location filename="../formsaildefbase.ui" line="1433"/>
        <source>Sheeting angle</source>
        <translation>Ouverture de la voile</translation>
    </message>
    <message encoding="UTF-8">
        <source>m²</source>
        <translation type="obsolete">m²</translation>
    </message>
    <message>
        <location filename="../formsaildefbase.ui" line="451"/>
        <source>Sail area</source>
        <translation>Surface de la voile</translation>
    </message>
    <message>
        <location filename="../formsaildefbase.ui" line="444"/>
        <source>Diagonal</source>
        <translation>Diagonale</translation>
    </message>
    <message>
        <location filename="../formsaildefbase.ui" line="898"/>
        <source>Compute</source>
        <translation>Calculer</translation>
    </message>
    <message>
        <source>Sail ID</source>
        <translation type="obsolete">Identification de la voile</translation>
    </message>
    <message>
        <location filename="../formsaildefbase.ui" line="1049"/>
        <source>Number of luff gores</source>
        <translation>Nombre de fuseaux guindant</translation>
    </message>
    <message>
        <location filename="../formsaildefbase.ui" line="583"/>
        <source>Dihedral angle</source>
        <translation>Angle de dièdre</translation>
    </message>
    <message>
        <location filename="../formsaildefbase.ui" line="615"/>
        <source>Wing</source>
        <translation>Aile</translation>
    </message>
    <message>
        <location filename="../formsaildefbase.ui" line="496"/>
        <source>Sail identifier</source>
        <translation>Identifiant de la voile</translation>
    </message>
    <message>
        <location filename="../formsaildefbase.ui" line="474"/>
        <source>m2</source>
        <translation>m2</translation>
    </message>
    <message>
        <location filename="../formsaildefbase.ui" line="643"/>
        <source>Luff rake</source>
        <translation>Quête du guindant</translation>
    </message>
    <message>
        <location filename="../formsaildefbase.ui" line="1176"/>
        <source>Mitre cut 2</source>
        <translation>Coupe mître 2</translation>
    </message>
    <message>
        <location filename="../formsaildefbase.ui" line="1532"/>
        <source>Foot hem</source>
        <translation>Ourlet bordure</translation>
    </message>
    <message>
        <location filename="../formsaildefbase.ui" line="530"/>
        <source>Sail name</source>
        <translation>Nom de la voile</translation>
    </message>
</context>
<context>
    <name>CRigSailWidget</name>
    <message>
        <source>Sail information</source>
        <translation type="obsolete">Informations sur la voile</translation>
    </message>
    <message>
        <source>file</source>
        <translation type="obsolete">fichier</translation>
    </message>
    <message>
        <source>name</source>
        <translation type="obsolete">nom</translation>
    </message>
    <message>
        <source>Remove</source>
        <translation type="obsolete">Retirer</translation>
    </message>
    <message>
        <source>Update</source>
        <translation type="obsolete">Mettre a jour</translation>
    </message>
    <message>
        <source>Reload</source>
        <translation type="obsolete">Recharger</translation>
    </message>
    <message>
        <source>error</source>
        <translation type="obsolete">erreur</translation>
    </message>
    <message>
        <source>There was an error reading from the selected file.</source>
        <translation type="obsolete">Une erreur s&apos;est produite lors de la lecture du fichier sélectionné.</translation>
    </message>
</context>
<context>
    <name>CSailDataPrinter</name>
    <message>
        <location filename="../sailprinter.cpp" line="44"/>
        <source>Sailcut CAD data sheet</source>
        <translation>Données Sailcut CAD</translation>
    </message>
    <message>
        <location filename="../sailprinter.cpp" line="50"/>
        <source>Mainsail</source>
        <translation>Grand-voile</translation>
    </message>
    <message>
        <location filename="../sailprinter.cpp" line="53"/>
        <source>Jib</source>
        <translation>Foc</translation>
    </message>
    <message>
        <location filename="../sailprinter.cpp" line="56"/>
        <source>Wing</source>
        <translation>Aile</translation>
    </message>
    <message>
        <location filename="../sailprinter.cpp" line="56"/>
        <source>deg</source>
        <translation>deg</translation>
    </message>
    <message>
        <location filename="../sailprinter.cpp" line="59"/>
        <source>Sail type</source>
        <translation>Type de voile</translation>
    </message>
    <message>
        <location filename="../sailprinter.cpp" line="65"/>
        <source>Cross Cut</source>
        <translation>Coupe transverse</translation>
    </message>
    <message>
        <location filename="../sailprinter.cpp" line="68"/>
        <source>Horizontal Cut</source>
        <translation>Coupe horizontale</translation>
    </message>
    <message>
        <location filename="../sailprinter.cpp" line="71"/>
        <source>Radial Cut</source>
        <translation>Coupe radiale</translation>
    </message>
    <message>
        <location filename="../sailprinter.cpp" line="72"/>
        <source>sections</source>
        <translation>sections</translation>
    </message>
    <message>
        <location filename="../sailprinter.cpp" line="73"/>
        <source>head gores</source>
        <translation>fuseaux de tête</translation>
    </message>
    <message>
        <location filename="../sailprinter.cpp" line="74"/>
        <source>luff gores</source>
        <translation>fuseaux de guindant</translation>
    </message>
    <message>
        <location filename="../sailprinter.cpp" line="77"/>
        <source>Twist Foot Cut</source>
        <translation>Coupe twist foot</translation>
    </message>
    <message>
        <location filename="../sailprinter.cpp" line="80"/>
        <source>Vertical Cut</source>
        <translation>Coupe verticale</translation>
    </message>
    <message>
        <location filename="../sailprinter.cpp" line="83"/>
        <source>Mitre Cut</source>
        <translation>Coupe à mitre</translation>
    </message>
    <message>
        <location filename="../sailprinter.cpp" line="86"/>
        <source>Mitre Cut 2</source>
        <translation>Coupe à mître 2</translation>
    </message>
    <message>
        <location filename="../sailprinter.cpp" line="89"/>
        <source>Sail layout</source>
        <translation>Type de coupe</translation>
    </message>
    <message>
        <location filename="../sailprinter.cpp" line="92"/>
        <source>Rig</source>
        <translation>Gréement</translation>
    </message>
    <message>
        <location filename="../sailprinter.cpp" line="93"/>
        <source>Boat LOA</source>
        <translation>Longueur du bateau</translation>
    </message>
    <message>
        <source>Mast/Luff rake</source>
        <translation type="obsolete">Quête du mât / guidant</translation>
    </message>
    <message>
        <location filename="../sailprinter.cpp" line="95"/>
        <source>Tack position X</source>
        <translation>Position X de l&apos;amure</translation>
    </message>
    <message>
        <location filename="../sailprinter.cpp" line="96"/>
        <source>Tack height Y</source>
        <translation>Hauteur Y de l&apos;amure</translation>
    </message>
    <message>
        <location filename="../sailprinter.cpp" line="97"/>
        <source>Fore triangle hoist I</source>
        <translation>Hauteur I du triangle avant</translation>
    </message>
    <message>
        <location filename="../sailprinter.cpp" line="98"/>
        <source>Fore triangle base J</source>
        <translation>Base J du triangle avant</translation>
    </message>
    <message>
        <location filename="../sailprinter.cpp" line="101"/>
        <source>Sail dimensions</source>
        <translation>Dimensions de la voile</translation>
    </message>
    <message>
        <location filename="../sailprinter.cpp" line="102"/>
        <source>Luff length</source>
        <translation>Longueur guindant</translation>
    </message>
    <message>
        <location filename="../sailprinter.cpp" line="103"/>
        <source>Foot length</source>
        <translation>Longueur bordure</translation>
    </message>
    <message>
        <location filename="../sailprinter.cpp" line="104"/>
        <source>Leech length</source>
        <translation>Longueur chute</translation>
    </message>
    <message>
        <location filename="../sailprinter.cpp" line="105"/>
        <source>Gaff length</source>
        <translation>Longueur vergue</translation>
    </message>
    <message>
        <location filename="../sailprinter.cpp" line="106"/>
        <source>Gaff angle wrt luff</source>
        <translation>Angle vergue / guindant</translation>
    </message>
    <message>
        <location filename="../sailprinter.cpp" line="109"/>
        <source>Shape of edges</source>
        <translation>Forme des bords</translation>
    </message>
    <message>
        <location filename="../sailprinter.cpp" line="110"/>
        <source>Luff round</source>
        <translation>Rond du guindant</translation>
    </message>
    <message>
        <location filename="../sailprinter.cpp" line="111"/>
        <source>Luff round position</source>
        <translation>Position du rond de guindant</translation>
    </message>
    <message>
        <location filename="../sailprinter.cpp" line="112"/>
        <source>Foot round</source>
        <translation>Rond de la bordure</translation>
    </message>
    <message>
        <location filename="../sailprinter.cpp" line="113"/>
        <source>Foot round position</source>
        <translation>Position du rond de bordure</translation>
    </message>
    <message>
        <location filename="../sailprinter.cpp" line="114"/>
        <source>Leech round</source>
        <translation>Rond de la chute</translation>
    </message>
    <message>
        <location filename="../sailprinter.cpp" line="115"/>
        <source>Leech round position</source>
        <translation>Position du rond de chute</translation>
    </message>
    <message>
        <location filename="../sailprinter.cpp" line="116"/>
        <source>Gaff round</source>
        <translation>Rond de la vergue</translation>
    </message>
    <message>
        <location filename="../sailprinter.cpp" line="117"/>
        <source>Gaff round position</source>
        <translation>Position du rond de la gaffe</translation>
    </message>
    <message>
        <location filename="../sailprinter.cpp" line="120"/>
        <source>Sail settings</source>
        <translation>Réglage de la voile</translation>
    </message>
    <message>
        <location filename="../sailprinter.cpp" line="121"/>
        <source>Twist angle</source>
        <translation>Angle de vrillage</translation>
    </message>
    <message>
        <location filename="../sailprinter.cpp" line="122"/>
        <source>Sheeting angle</source>
        <translation>Angle de tire</translation>
    </message>
    <message>
        <location filename="../sailprinter.cpp" line="125"/>
        <source>Cloth seams and hems</source>
        <translation>Tissu, coutures et ourlets</translation>
    </message>
    <message>
        <location filename="../sailprinter.cpp" line="126"/>
        <source>Cloth width</source>
        <translation>Largeur du tissu</translation>
    </message>
    <message>
        <location filename="../sailprinter.cpp" line="127"/>
        <source>Seams width</source>
        <translation>Largeur des coutures</translation>
    </message>
    <message>
        <location filename="../sailprinter.cpp" line="128"/>
        <source>Leech hem width</source>
        <translation>Largeur pour ourlet chute</translation>
    </message>
    <message>
        <location filename="../sailprinter.cpp" line="129"/>
        <source>Foot hem width</source>
        <translation>Largeur pour ourlet bordure</translation>
    </message>
    <message>
        <location filename="../sailprinter.cpp" line="130"/>
        <source>Other hems width</source>
        <translation>Largeur pour autres ourlets</translation>
    </message>
    <message>
        <location filename="../sailprinter.cpp" line="133"/>
        <source>Sail mould</source>
        <translation>Moule de voile</translation>
    </message>
    <message>
        <location filename="../sailprinter.cpp" line="134"/>
        <source>Luff factor</source>
        <translation>Forme guindant</translation>
    </message>
    <message>
        <location filename="../sailprinter.cpp" line="134"/>
        <source>Depth</source>
        <translation>Creux</translation>
    </message>
    <message>
        <location filename="../sailprinter.cpp" line="134"/>
        <source>Leech factor</source>
        <translation>Forme chute</translation>
    </message>
    <message>
        <location filename="../sailprinter.cpp" line="136"/>
        <source>Top profile</source>
        <translation>Profil supérieur</translation>
    </message>
    <message>
        <location filename="../sailprinter.cpp" line="142"/>
        <source>Mid profile at h = </source>
        <translation>Profil médian à h =</translation>
    </message>
    <message>
        <location filename="../sailprinter.cpp" line="148"/>
        <source>Bottom profile</source>
        <translation>Profil inférieur</translation>
    </message>
    <message>
        <location filename="../sailprinter.cpp" line="94"/>
        <source>Luff rake</source>
        <translation></translation>
    </message>
</context>
<context>
    <name>CSailDevelPrinter</name>
    <message>
        <location filename="../sailprinter.cpp" line="190"/>
        <source>Scale</source>
        <translation>Echelle</translation>
    </message>
</context>
<context>
    <name>CSailDispGL</name>
    <message>
        <source>This system has no OpenGL support.</source>
        <translation type="obsolete">OpenGL n&apos;est pas disponible sur cette machine.</translation>
    </message>
</context>
<context>
    <name>CSailDrawingPrinter</name>
    <message>
        <location filename="../sailprinter.cpp" line="221"/>
        <source>Scale</source>
        <translation>Echelle</translation>
    </message>
</context>
<context>
    <name>CSailPrinter</name>
    <message>
        <source>Sailcut CAD data sheet</source>
        <translation type="obsolete">Données Sailcut CAD</translation>
    </message>
    <message>
        <source>Mainsail</source>
        <translation type="obsolete">Grand-voile</translation>
    </message>
    <message>
        <source>Jib</source>
        <translation type="obsolete">Foc</translation>
    </message>
    <message>
        <source>Wing</source>
        <translation type="obsolete">Aile</translation>
    </message>
    <message>
        <source>deg</source>
        <translation type="obsolete">deg</translation>
    </message>
    <message>
        <source>Sail type</source>
        <translation type="obsolete">Type de voile</translation>
    </message>
    <message>
        <source>Cross Cut</source>
        <translation type="obsolete">Coupe transverse</translation>
    </message>
    <message>
        <source>Horizontal Cut</source>
        <translation type="obsolete">Coupe horizontale</translation>
    </message>
    <message>
        <source>Radial Cut</source>
        <translation type="obsolete">Coupe radiale</translation>
    </message>
    <message>
        <source>sections</source>
        <translation type="obsolete">sections</translation>
    </message>
    <message>
        <source>head gores</source>
        <translation type="obsolete">fuseaux de tête</translation>
    </message>
    <message>
        <source>luff gores</source>
        <translation type="obsolete">fuseaux de guindant</translation>
    </message>
    <message>
        <source>Twist Foot Cut</source>
        <translation type="obsolete">Coupe twist foot</translation>
    </message>
    <message>
        <source>Vertical Cut</source>
        <translation type="obsolete">Coupe verticale</translation>
    </message>
    <message>
        <source>Mitre Cut</source>
        <translation type="obsolete">Coupe à mitre</translation>
    </message>
    <message>
        <source>Sail layout</source>
        <translation type="obsolete">Type de coupe</translation>
    </message>
    <message>
        <source>Rig</source>
        <translation type="obsolete">Gréement</translation>
    </message>
    <message>
        <source>Boat LOA</source>
        <translation type="obsolete">Longueur du bateau</translation>
    </message>
    <message>
        <source>Mast/Luff rake</source>
        <translation type="obsolete">Quête du mât / guidant</translation>
    </message>
    <message>
        <source>Tack position X</source>
        <translation type="obsolete">Position X de l&apos;amure</translation>
    </message>
    <message>
        <source>Tack height Y</source>
        <translation type="obsolete">Hauteur Y de l&apos;amure</translation>
    </message>
    <message>
        <source>Fore triangle hoist I</source>
        <translation type="obsolete">Hauteur I du triangle avant</translation>
    </message>
    <message>
        <source>Fore triangle base J</source>
        <translation type="obsolete">Base J du triangle avant</translation>
    </message>
    <message>
        <source>Sail dimensions</source>
        <translation type="obsolete">Dimensions de la voile</translation>
    </message>
    <message>
        <source>Luff length</source>
        <translation type="obsolete">Longueur guindant</translation>
    </message>
    <message>
        <source>Foot length</source>
        <translation type="obsolete">Longueur bordure</translation>
    </message>
    <message>
        <source>Leech length</source>
        <translation type="obsolete">Longueur chute</translation>
    </message>
    <message>
        <source>Gaff length</source>
        <translation type="obsolete">Longueur vergue</translation>
    </message>
    <message>
        <source>Gaff angle wrt luff</source>
        <translation type="obsolete">Angle vergue / guindant</translation>
    </message>
    <message>
        <source>Shape of edges</source>
        <translation type="obsolete">Forme des bords</translation>
    </message>
    <message>
        <source>Luff round</source>
        <translation type="obsolete">Rond du guindant</translation>
    </message>
    <message>
        <source>Luff round position</source>
        <translation type="obsolete">Position du rond de guindant</translation>
    </message>
    <message>
        <source>Foot round</source>
        <translation type="obsolete">Rond de la bordure</translation>
    </message>
    <message>
        <source>Foot round position</source>
        <translation type="obsolete">Position du rond de bordure</translation>
    </message>
    <message>
        <source>Leech round</source>
        <translation type="obsolete">Rond de la chute</translation>
    </message>
    <message>
        <source>Leech round position</source>
        <translation type="obsolete">Position du rond de chute</translation>
    </message>
    <message>
        <source>Gaff round</source>
        <translation type="obsolete">Rond de la vergue</translation>
    </message>
    <message>
        <source>Gaff round position</source>
        <translation type="obsolete">Position du rond de la gaffe</translation>
    </message>
    <message>
        <source>Sail settings</source>
        <translation type="obsolete">Réglage de la voile</translation>
    </message>
    <message>
        <source>Twist angle</source>
        <translation type="obsolete">Angle de vrillage</translation>
    </message>
    <message>
        <source>Sheeting angle</source>
        <translation type="obsolete">Ouverture de la voile</translation>
    </message>
    <message>
        <source>Cloth seams and hems</source>
        <translation type="obsolete">Tissu, coutures et ourlets</translation>
    </message>
    <message>
        <source>Cloth width</source>
        <translation type="obsolete">Largeur du tissu</translation>
    </message>
    <message>
        <source>Seams width</source>
        <translation type="obsolete">Largeur des coutures</translation>
    </message>
    <message>
        <source>Leech hem width</source>
        <translation type="obsolete">Largeur pour ourlet chute</translation>
    </message>
    <message>
        <source>Other hem width</source>
        <translation type="obsolete">Largeur pour autres ourlets</translation>
    </message>
    <message>
        <source>Sail mould</source>
        <translation type="obsolete">Moule de voile</translation>
    </message>
    <message>
        <source>Luff factor</source>
        <translation type="obsolete">Forme guindant</translation>
    </message>
    <message>
        <source>Depth</source>
        <translation type="obsolete">Creux</translation>
    </message>
    <message>
        <source>Leech factor</source>
        <translation type="obsolete">Forme chute</translation>
    </message>
    <message>
        <source>Top profile</source>
        <translation type="obsolete">Profil supérieur</translation>
    </message>
    <message>
        <source>Mid profile at h = </source>
        <translation type="obsolete">Profil médian à h =</translation>
    </message>
    <message>
        <source>Bottom profile</source>
        <translation type="obsolete">Profil inférieur</translation>
    </message>
</context>
<context>
    <name>CSailViewerPanel</name>
    <message>
        <location filename="../sailviewer-panel.cpp" line="137"/>
        <source>Display parameters</source>
        <translation>Paramètres d&apos;affichage</translation>
    </message>
    <message>
        <location filename="../sailviewer-panel.cpp" line="138"/>
        <source>elevation</source>
        <translation>élévation</translation>
    </message>
    <message>
        <location filename="../sailviewer-panel.cpp" line="139"/>
        <source>azimuth</source>
        <translation>azimuth</translation>
    </message>
    <message>
        <location filename="../sailviewer-panel.cpp" line="141"/>
        <source>Controls</source>
        <translation>Controles</translation>
    </message>
    <message>
        <location filename="../sailviewer-panel.cpp" line="142"/>
        <source>Reset view</source>
        <translation>Réinitialiser la vue</translation>
    </message>
    <message>
        <location filename="../sailviewer-panel.cpp" line="145"/>
        <source>Labeling</source>
        <translation>Etiquettes</translation>
    </message>
    <message>
        <location filename="../sailviewer-panel.cpp" line="147"/>
        <source>Zoom in</source>
        <translation>Zoom avant</translation>
    </message>
    <message>
        <location filename="../sailviewer-panel.cpp" line="148"/>
        <source>Zoom out</source>
        <translation>Zoom arrière</translation>
    </message>
    <message>
        <location filename="../sailviewer-panel.cpp" line="186"/>
        <source>deg</source>
        <translation>deg</translation>
    </message>
</context>
<context>
    <name>CSailViewerTabs</name>
    <message>
        <location filename="../sailviewer-tabs.cpp" line="60"/>
        <source>shaded view</source>
        <translation>vue rendu 3D</translation>
    </message>
    <message>
        <location filename="../sailviewer-tabs.cpp" line="62"/>
        <source>wireframe view</source>
        <translation>vue fil de  fer</translation>
    </message>
</context>
<context>
    <name>CWidgetProfile</name>
    <message>
        <location filename="../widgetprofile.cpp" line="245"/>
        <source>%</source>
        <translation>%</translation>
    </message>
    <message>
        <location filename="../widgetprofile.cpp" line="243"/>
        <source>Luff shape</source>
        <translation>Forme guindant</translation>
    </message>
    <message>
        <location filename="../widgetprofile.cpp" line="244"/>
        <source>Depth</source>
        <translation>Creux</translation>
    </message>
    <message>
        <location filename="../widgetprofile.cpp" line="246"/>
        <source>Leech shape</source>
        <translation>Forme chute</translation>
    </message>
    <message>
        <location filename="../widgetprofile.cpp" line="250"/>
        <source>degrees</source>
        <translation>degrés</translation>
    </message>
    <message>
        <location filename="../widgetprofile.cpp" line="249"/>
        <source>cord</source>
        <translation>corde</translation>
    </message>
</context>
<context>
    <name>Dialog</name>
    <message>
        <source>Dialog</source>
        <translation type="obsolete">Dialogue</translation>
    </message>
    <message>
        <source>All panels in a single file</source>
        <translation type="obsolete">Tous les panneaux dans un seul fichier</translation>
    </message>
    <message>
        <source>One file per panel</source>
        <translation type="obsolete">Un fichier par panneau</translation>
    </message>
</context>
<context>
    <name>XmlReaderTempl</name>
    <message>
        <source>error</source>
        <translation type="obsolete">erreur</translation>
    </message>
    <message>
        <source>There was an error reading from the selected file.</source>
        <translation type="obsolete">Une erreur s&apos;est produite à la lecture du fichier sélectionné.</translation>
    </message>
</context>
</TS>
